==> alg-alg-2.3.11-20190705.122929-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/AutoBiddingDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

public class AutoBiddingDo {
    /**
     * 广告
     */
    private Long advertId;


    /**
     * 配置ID
     */
    private Long planId;


    /**
     * 媒体ID
     */
    private Long appId;




    /**
     * 投放目标类型
     */
    private Long baseType;

    /**
     * 辅助目标类型
     */
    private Long secondSubType;

    /**
     * 广告后端转化率
     */
    private Double adBCvr;


    /**
     *广告媒体后端转化率
     */
    private Double adAndappBCvr;

    /**
     * 广告前端pv
     */
    private Long adBasePv;


    /**
     *广告媒体前端pv
     */
    private Long adAndappBasePv;

    /**
     * 原始目标出价
     */
    private Long aFee;


    /**
     * 媒体目标出价调节因子
     */
    private Double appAfeeFactor;



    private Double controlWeight;


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getBaseType() {
        return baseType;
    }

    public void setBaseType(Long baseType) {
        this.baseType = baseType;
    }

    public Long getSecondSubType() {
        return secondSubType;
    }

    public void setSecondSubType(Long secondSubType) {
        this.secondSubType = secondSubType;
    }

    public Double getAdBCvr() {
        return adBCvr;
    }

    public void setAdBCvr(Double adBCvr) {
        this.adBCvr = adBCvr;
    }

    public Double getAdAndappBCvr() {
        return adAndappBCvr;
    }

    public void setAdAndappBCvr(Double adAndappBCvr) {
        this.adAndappBCvr = adAndappBCvr;
    }

    public Long getaFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public Double getAppAfeeFactor() {
        return appAfeeFactor;
    }

    public void setAppAfeeFactor(Double appAfeeFactor) {
        this.appAfeeFactor = appAfeeFactor;
    }

    public Long getAdBasePv() {
        return adBasePv;
    }

    public void setAdBasePv(Long adBasePv) {
        this.adBasePv = adBasePv;
    }

    public Long getAdAndappBasePv() {
        return adAndappBasePv;
    }

    public void setAdAndappBasePv(Long adAndappBasePv) {
        this.adAndappBasePv = adAndappBasePv;
    }

    public Double getControlWeight() {
        return controlWeight;
    }

    public void setControlWeight(Double controlWeight) {
        this.controlWeight = controlWeight;
    }


}

==> alg-alg-2.22.3-20201105.130519-2-sources.jar: cn/com/duiba/nezha/alg/alg/vo/AutoBiddingDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

public class AutoBiddingDo {
    /**
     * 广告
     */
    private Long advertId;


    /**
     * 配置ID
     */
    private Long planId;


    /**
     * 媒体ID
     */
    private Long appId;


    /**
     * 消耗
     */
    private Long comsume;


    /**
     * 转化量
     */
    private Long convert_type_pv;




    /**
     * 投放目标类型
     */
    private Long baseType;

    /**
     * 辅助目标类型
     */
    private Long secondSubType;

    /**
     * 广告后端转化率
     */
    private Double adBCvr;


    /**
     *广告媒体后端转化率
     */
    private Double adAndappBCvr;

    /**
     * 广告前端pv
     */
    private Long adBasePv;


    /**
     *广告媒体前端pv
     */
    private Long adAndappBasePv;

    /**
     * 原始目标出价
     */
    private Long aFee;


    /**
     * 媒体目标出价调节因子
     */
    private Double appAfeeFactor;



    private Double controlWeight;


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getBaseType() {
        return baseType;
    }

    public void setBaseType(Long baseType) {
        this.baseType = baseType;
    }

    public Long getSecondSubType() {
        return secondSubType;
    }

    public void setSecondSubType(Long secondSubType) {
        this.secondSubType = secondSubType;
    }

    public Double getAdBCvr() {
        return adBCvr;
    }

    public void setAdBCvr(Double adBCvr) {
        this.adBCvr = adBCvr;
    }

    public Double getAdAndappBCvr() {
        return adAndappBCvr;
    }

    public void setAdAndappBCvr(Double adAndappBCvr) {
        this.adAndappBCvr = adAndappBCvr;
    }

    public Long getaFee() {
        return aFee;
    }

    public void setaFee(Long aFee) {
        this.aFee = aFee;
    }

    public Double getAppAfeeFactor() {
        return appAfeeFactor;
    }

    public void setAppAfeeFactor(Double appAfeeFactor) {
        this.appAfeeFactor = appAfeeFactor;
    }

    public Long getAdBasePv() {
        return adBasePv;
    }

    public void setAdBasePv(Long adBasePv) {
        this.adBasePv = adBasePv;
    }

    public Long getAdAndappBasePv() {
        return adAndappBasePv;
    }

    public void setAdAndappBasePv(Long adAndappBasePv) {
        this.adAndappBasePv = adAndappBasePv;
    }

    public Double getControlWeight() {
        return controlWeight;
    }

    public void setControlWeight(Double controlWeight) {
        this.controlWeight = controlWeight;
    }

    public Long getComsume() {
        return comsume;
    }

    public void setComsume(Long comsume) {
        this.comsume = comsume;
    }

    public Long getConvert_type_pv() {
        return convert_type_pv;
    }

    public void setConvert_type_pv(Long convert_type_pv) {
        this.convert_type_pv = convert_type_pv;
    }
}
